import { __assign, __awaiter, __generator, __spreadArray } from "tslib";
import * as React from "react";
var R = React;
/**
 * Creates a query from an async getter function.
 *
 * ```ts
 * const query = useCreateQuery(async () => {
 *  const response = await fetch("https://example.com");
 *  return response.json();
 * });
 * ```
 */
export var useCreateQuery = function (getter, dependencies) {
    var _a = R.useReducer(function (state, action) {
        switch (action.type) {
            case "load":
                return __assign(__assign({}, state), { isSuccess: false, isError: false, isFetching: false, isLoading: true, isUninitialized: false });
            case "fetch":
                return __assign(__assign({}, state), { isLoading: false, isSuccess: false, isError: false, isFetching: true, isUninitialized: false });
            case "success":
                return __assign(__assign({}, state), { isLoading: false, isFetching: false, isError: false, isUninitialized: false, isSuccess: true, data: action.payload.data });
            case "error":
                return __assign(__assign({}, state), { isLoading: false, isSuccess: false, isFetching: false, isUninitialized: false, isError: true, error: action.payload.error });
            default:
                return state;
        }
    }, {
        isLoading: true,
        isSuccess: false,
        isError: false,
        isFetching: false,
        refetch: function () { },
        isUninitialized: true,
        currentData: undefined,
        data: undefined,
        error: undefined,
        endpointName: "",
        fulfilledTimeStamp: 0,
        originalArgs: undefined,
        requestId: "",
        startedTimeStamp: 0
    }), state = _a[0], dispatch = _a[1];
    R.useEffect(function () {
        if (state.data === undefined) {
            dispatch({ type: "load" });
        }
        else {
            dispatch({ type: "fetch" });
        }
        var fetchData = function () { return __awaiter(void 0, void 0, void 0, function () {
            var data, error_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 2, , 3]);
                        return [4 /*yield*/, getter()];
                    case 1:
                        data = _a.sent();
                        dispatch({ type: "success", payload: { data: data } });
                        return [3 /*break*/, 3];
                    case 2:
                        error_1 = _a.sent();
                        dispatch({ type: "error", payload: { error: error_1 } });
                        return [3 /*break*/, 3];
                    case 3: return [2 /*return*/];
                }
            });
        }); };
        fetchData();
    }, __spreadArray([], (dependencies !== null && dependencies !== void 0 ? dependencies : []), true));
    return state;
};
export var _testCreateUseCreateQuery = function (react) {
    R = react;
    return useCreateQuery;
};
//# sourceMappingURL=createQuery.js.map